@@ -17,6 +17,7 @@ def get_package_version(file_path):
 ALLOWED_HOSTS_DEV = [
     '127.0.0.1',
     'localhost',
+    'home'
 ]
 
 INSTALLED_APPS = [
@@ -119,6 +120,7 @@ STATICFILES_FINDERS = [
 ]
 
 RICH_TEXT_FEATURES = [
+    'h1',
     'h2',
     'h3',
     'h4',
@@ -191,5 +193,15 @@ LOGGING = {
             'propagate': True,
             'level': 'DEBUG',
         },
+        'email': {
+            'level': 'DEBUG',
+            'propagate': True,
+            'handlers': ['console'],
+        },
+        'bakery': {
+            'level': 'DEBUG',
+            'propagate': True,
+            'handlers': ['console'],
+        }
     }
 }
