@@ -38,7 +38,7 @@ class BuildableModel(models.Model):
         self._build_related()
 
     def get_absolute_url(self):
-        pass
+        return self.get_full_url()
 
     class Meta:
         abstract = True
@@ -53,7 +53,7 @@ class WagtailPageBakeryModel(BuildableModel):
 
         #  Remove settings.DEBUG if you want to test static page
 
-        if settings.DEBUG or request.is_preview or is_building:
+        if request.is_preview or is_building:
             return TemplateResponse(
                 request,
                 self.get_template(request, *args, **kwargs),
