@@ -32,6 +32,8 @@ from webspace.cms.forms.abstract import FormMixin
 from webspace.loader import get_model, get_class
 
 GenericPage = get_model('cms', 'GenericPage')
+Person = get_model('cms', 'Person')
+
 TextEntry = get_class('cms.blocks.entries', 'TextEntry')
 
 
@@ -46,7 +48,7 @@ class ABlogPageTag(TaggedItemBase):
 class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
     template = '%s/blog_page.html' % constants.PAGES_TEMPLATES_PATH
     author = models.ForeignKey(
-        settings.WAGTAIL_BLOG_AUTHOR_PAGE,
+        Person,
         blank=True,
         null=True,
         on_delete=models.SET_NULL,
