@@ -17,6 +17,7 @@ class AIconSnippet(index.Indexed, models.Model):
         blank=True,
         on_delete=models.SET_NULL,
         related_name='+',
+        verbose_name="Theme Secondary"
     )
     space = models.ForeignKey(
         MyDocument,
@@ -24,12 +25,13 @@ class AIconSnippet(index.Indexed, models.Model):
         blank=True,
         on_delete=models.SET_NULL,
         related_name='+',
+        verbose_name="Theme Primary"
     )
 
     panels = [
         FieldPanel('key'),
-        DocumentChooserPanel('light'),
         DocumentChooserPanel('space'),
+        DocumentChooserPanel('light'),
     ]
 
     search_fields = [
