@@ -22,7 +22,9 @@ SIZES_IMG = {
 
 AMP_SCRIPTS = {
     'carousel': "<script async custom-element='amp-carousel' src='https://cdn.ampproject.org/v0/amp-carousel-0.2.js'></script>",
-    'iframe': "<script async custom-element='amp-iframe' src='https://cdn.ampproject.org/v0/amp-iframe-0.1.js'></script>"
+    'iframe': "<script async custom-element='amp-iframe' src='https://cdn.ampproject.org/v0/amp-iframe-0.1.js'></script>",
+    'accordion': "<script async custom-element='amp-accordion' src='https://cdn.ampproject.org/v0/amp-accordion-0.1.js'></script>",
+    'form': "<script async custom-element='amp-form' src='https://cdn.ampproject.org/v0/amp-form-0.1.js'></script>"
 }
 
 
@@ -123,10 +125,14 @@ def amp_scripts(context):
                     if block.block_type == 'cards' and script == 'carousel':
                         if block.value['carousel']:
                             scripts.append(script)
-                    if block.block_type == 'media_text' and script == 'iframe':
-                        for media in block.value['media']:
+                    if block.block_type == 'component_text' and script == 'iframe':
+                        for media in block.value['component']:
                             if media.block_type == 'embed':
                                 scripts.append(script)
+                    if block.block_type == 'component_text' and script == 'form':
+                        for media in block.value['component']:
+                            if media.block_type == 'form':
+                                scripts.append(script)
                     else:
                         scripts.append(script)
     html = ''
@@ -144,7 +150,7 @@ def amp_canonical(context):
         return {
             'content': "<link rel='amphtml' href='https://%s" % context[
                 'request'].get_host() + "/amp%s'>" % context[
-                'request'].path.replace('?build=true', '')
+                           'request'].path.replace('?build=true', '')
         }
     return None
 
